@@ -14,7 +14,7 @@ import cloudscraper  # type: ignore
 user_agent = {"User-Agent": "git.io/wanda"}
 content_json = "application/json"
 folder = f"{str(Path.home())}/wanda"
-version = "0.60.2"
+version = "0.60.3"
 
 
 def is_connected():
@@ -358,7 +358,7 @@ def picsum(search=None):
 
 def imgur(search=None):
     if search:
-        imgur_url = f"https://rimgo.pussthecat.org/gallery/{search}"
+        imgur_url = f"https://rimgo.pussthecat.org/a/{search}"
     else:
         search = ""
         if screen_orientation() == "portrait":
@@ -373,7 +373,7 @@ def get_imgur_image(imgur_url, alt="rimgo.pussthecat.org"):
     from lxml import html
 
     tree = html.fromstring(get(imgur_url.replace("imgur.com", f"{alt}")).content)
-    images = tree.xpath("//div[@class='center']//img/@src")
+    images = tree.xpath("//div[contains(@class,'post__media')]//img/@src")
     return f"https://{alt}{random.choice(images)}" if images else no_results()
 
 
@@ -496,13 +496,13 @@ def local(path):
 
 def waifuim(search=None):
     orientation = "PORTRAIT" if screen_orientation() == "portrait" else "LANDSCAPE"
-    accept = f"&selected_tags={search}" if search else ""
+    accept = f"&included_tags={search}" if search else ""
     reject = ""
     if search and "-" in search:
         accept = f"&selected_tags={search.split('-')[0]}"
         reject = f"&excluded_tags={search.split('-')[1]}"
     api = (
-        f"https://api.waifu.im/random/?gif=false&is_nsfw=false"
+        f"https://api.waifu.im/search/?gif=false&is_nsfw=false"
         f"&orientation={orientation}{accept}{reject}"
     )
     response = get(api).json()
